@@ -37,17 +37,19 @@ def register_graphql_schema(schema_cls):
     return schema_cls
 
 
-def register_field_middleware(field_name: str, middleware):
-    assert isinstance(middleware, list), "middleware should be list but got {}.".format(
-        type(middleware)
-    )
+def register_field_middleware(field_name: str, middleware_list: list):
+    if not isinstance(middleware_list, list):
+        raise TypeError(
+            f"middleware_list should be a list, got {type(middleware_list)}"
+        )
+
     if grapple_settings.AUTO_CAMELCASE:
         field_name = to_camel_case(field_name)
 
     if field_name in field_middlewares:
-        field_middlewares[field_name] += middleware
+        field_middlewares[field_name] += middleware_list
     else:
-        field_middlewares[field_name] = middleware
+        field_middlewares[field_name] = middleware_list
 
 
 def register_query_field(
@@ -89,6 +91,10 @@ def register_query_field(
                 if not kwargs:
                     return None
 
+                for k, v in dict(kwargs).items():
+                    if v is None:
+                        del kwargs[k]
+
                 try:
                     # If is a Page then only query live/public pages.
                     if issubclass(cls, Page):
@@ -147,6 +153,7 @@ def register_query_field(
             setattr(
                 schema, "resolve_" + field_name, MethodType(resolve_singular, schema)
             )
+
             setattr(
                 schema,
                 "resolve_" + plural_field_name,
@@ -204,6 +211,10 @@ def register_paginated_query_field(
                 if not kwargs:
                     return None
 
+                for k, v in dict(kwargs).items():
+                    if v is None:
+                        del kwargs[k]
+
                 try:
                     # If is a Page then only query live/public pages.
                     if issubclass(cls, Page):
